@@ -10,6 +10,7 @@ from laipvt.handler.middlewarehandler import HarborConfigHandler
 from laipvt.sysutil.util import path_join, ssh_obj, log, status_me
 from laipvt.sysutil.template import FileTemplate
 from laipvt.model.cmd import ComposeModel
+from laipvt.sysutil.command import BASH_RUN, TARGZ_DECOMPRESSION, CHMOD_USER_GROUP
 
 
 class HarborController(MiddlewareInterface):
@@ -19,19 +20,26 @@ class HarborController(MiddlewareInterface):
         self.harbor_conf_tmp = path_join("/tmp", "harbor.yml")
         self.harbor_conf_template = path_join(self.template, "config.tmpl")
         self.harbor_conf_file = path_join(self.base_dir, "harbor.yml")
+
+        self.harbor_service_template = path_join(self.template, "harbor.service.tmpl")
+        self.harbor_service_tmp = path_join("/tmp", "harbor.service")
+        self.harbor_service_file = "/usr/lib/systemd/system/harbor.service"
+
         self.habor_data = path_join(self.template, "data")
         self._docker_compose_file = path_join(self.base_dir, "docker-compose.yaml")
         self.harbor_cfg = HarborConfigHandler().get_config_with_check_result()
         self.harbor_cfg["harbor"]["log_location"] = path_join(self.base_dir, "var/log/harbor")
         self.harbor_cfg["harbor"]["data_volume"] = path_join(self.base_dir, "data")
-
+        self.harbor_cfg["harbor"]["deploy_path"] = self.base_dir
 
     def _generic_config(self):
         log.info("渲染分发 Harbor 安装包及配置文件")
-        for num_id in range(len(self.harbor_server)):
+        for server in self.harbor_server:
             FileTemplate(self.harbor_cfg, self.harbor_conf_template, self.harbor_conf_tmp).fill()
-            self.send_config_file(self.harbor_server[num_id], self.template, self.base_dir)
-            self.send_config_file(self.harbor_server[num_id], self.harbor_conf_tmp, self.harbor_conf_file)
+            FileTemplate(self.harbor_cfg, self.harbor_service_template, self.harbor_service_tmp).fill()
+            self.send_config_file(server=server, src=self.template, dest=self.base_dir)
+            self.send_config_file(server=server, src=self.harbor_conf_tmp, dest=self.harbor_conf_file)
+            self.send_config_file(server=server, src=self.harbor_service_tmp, dest=self.harbor_service_file)
 
     def ssh_cli(self):
         for server in self.harbor_server:
@@ -40,8 +48,10 @@ class HarborController(MiddlewareInterface):
 
     def _install_harbor(self):
         log.info("安装harbor")
-        cmd_list = ["/bin/bash {}".format(path_join(self.base_dir, "install.sh")),
-               "tar -zxmf {} -C {}".format(path_join(self.base_dir, "data.tar.gz"), self.base_dir)]
+        cmd_list = [
+            BASH_RUN.format(path_join(self.base_dir, "install.sh")),
+            TARGZ_DECOMPRESSION.format(path_join(self.base_dir, "data.tar.gz"), self.base_dir)
+        ]
         res_list = self.ssh_cli().run_cmdlist(cmd_list)
         for res in res_list:
             if res["code"] != 0:
@@ -49,8 +59,16 @@ class HarborController(MiddlewareInterface):
                 exit(2)
 
     def _chmod_data(self):
-        cmd_list = ["chown -R 999:999 {} {}".format(path_join(self.base_dir, "data", "database"), path_join(self.base_dir, "data", "redis")),
-               "chown -R 10000:10000 {} {}  ".format(path_join(self.base_dir, "data", "secret"), path_join(self.base_dir, "data", "registry"))]
+        cmd_list = [
+            CHMOD_USER_GROUP.format(
+                "999", "999",
+                path_join(self.base_dir, "data", "database"),
+                path_join(self.base_dir, "data", "redis")),
+            CHMOD_USER_GROUP.format(
+                "10000", "10000",
+                path_join(self.base_dir, "data", "secret"),
+                path_join(self.base_dir, "data", "registry"))
+        ]
         res_list = self.ssh_cli().run_cmdlist(cmd_list)
         for res in res_list:
             if res["code"] != 0:
