@@ -10,6 +10,8 @@ from laipvt.sysutil.util import path_join, log, status_me, walk_sql_path
 from laipvt.sysutil.conf import YamlConfig
 from laipvt.sysutil.gvalue import LAIPVT_BASE_DIR
 from laipvt.model.sql import SqlModule
+from laipvt.sysutil.command import CREATE_DB
+
 
 class IdentityController(MiddlewareInterface):
     def __init__(self, result: CheckResultHandler, handler: IdentityConfigHandler, template: str):
@@ -78,9 +80,7 @@ class IdentityController(MiddlewareInterface):
         db_info = walk_sql_path(path_join(self.template, "identity_sqls"))
         sql = SqlModule(host=self.master_host, port=self.port, user=self.user, passwd=self.password)
         for db_name, sql_files in db_info.items():
-            create_db = "create database If Not Exists {db_name} DEFAULT CHARSET utf8mb4 COLLATE utf8mb4_general_ci".format(
-                db_name=db_name
-            )
+            create_db = CREATE_DB.format(db_name=db_name)
             sql.insert_sql(create_db)
             sql.use_db(db_name)
             for sql_file in sql_files:
@@ -102,4 +102,5 @@ class IdentityController(MiddlewareInterface):
         self.send_docker_compose_file()
         self.restart()
 
-
+    def deploy(self):
+        self.deploy_identity()
