@@ -17,7 +17,8 @@ class RabbitmqController(MiddlewareInterface):
         self.rabbitmq_conf_tmp = path_join("/tmp", "rabbitmq.config")
         self.rabbitmq_conf_template = path_join(self.template, "config.tmpl")
         self.rabbitmq_conf_file = path_join(self.base_dir, "config/rabbitmq.conf")
-        self.rabbitmq_cfg["rabbitmq"]["ipaddress"] = self.handler.cfg["ipaddress"]
+        if self.rabbitmq_cfg["rabbitmq"]["is_deploy"]:
+            self.rabbitmq_cfg["rabbitmq"]["ipaddress"] = self.handler.cfg["ipaddress"]
         self.rabbitmq_service_file_template = path_join(self.template, "rabbitmq_service.tmpl")
         self.rabbitmq_service_file_dest = path_join("/tmp", "rabbitmq_service.yaml")
         self.rabbitmq_service_file_remote = path_join(self.base_dir, "svc", "rabbitmq_service.yaml")
@@ -119,4 +120,7 @@ class RabbitmqController(MiddlewareInterface):
             self._generic_config()
             self.start()
             self._check()
-            self.create_rabbitmq_service_kubernetes()
+        self.create_rabbitmq_service_kubernetes()
+
+    def deploy(self):
+        self.deploy_rabbitmq()
