@@ -9,7 +9,7 @@ from minio import Minio
 from laipvt.interface.serviceinterface import ServiceInterface
 from laipvt.sysutil.util import path_join, log, status_me, walk_sql_path
 from laipvt.model.sql import SqlModule
-
+from laipvt.sysutil.command import CREATE_DB, HELM_LIST, HELM_INSTALL_COMMANDER, COMMANDER_UPGRADE_INSTALL
 
 class CommanderController(ServiceInterface):
     def __init__(self, check_result, service_path):
@@ -21,6 +21,12 @@ class CommanderController(ServiceInterface):
         self.nginx_template = path_join(self.templates_dir, "nginx/http/nginx-commander.tmpl")
         self.nginx_tmp = path_join("/tmp", "nginx-commander.conf")
         self.nginx_file_remote = path_join(self.deploy_dir, "nginx/http/nginx-commander.conf")
+        if self.middleware_cfg["mysql"]["is_deploy"]:
+            self.mysql_host = "mysql.default.svc"
+            self.mysql_port = 3306
+        else:
+            self.mysql_host = self.middleware_cfg["mysql"]["ipaddress"][0]
+            self.mysql_port = self.middleware_cfg["mysql"]["port"]
 
     @status_me("commander")
     def init_commander_mysql(self):
@@ -30,9 +36,7 @@ class CommanderController(ServiceInterface):
         sql = SqlModule(host=self.middleware_cfg.mysql.ipaddress[0], port=int(self.middleware_cfg.mysql.port),
                         user=self.middleware_cfg.mysql.username, passwd=self.middleware_cfg.mysql.password)
         for db_name, sql_files in db_info.items():
-            create_db = "create database If Not Exists {db_name} DEFAULT CHARSET utf8mb4 COLLATE utf8mb4_general_ci".format(
-                db_name=db_name
-            )
+            create_db = CREATE_DB.format(db_name=db_name)
             sql.insert_sql(create_db)
             sql.import_from_dir(db_name, path_join(sql_path, db_name))
             #sql.use_db(db_name)
@@ -49,9 +53,7 @@ class CommanderController(ServiceInterface):
             for process in processes:
                 log.info("{}开始部署".format(process))
 
-                check_cmd = "helm --host=localhost:44134 list --all --chart-name {}|grep -q '{}'".format(
-                    process, process
-                )
+                check_cmd = HELM_LIST.format(process, process)
                 check_results = self._exec_command_to_host(cmd=check_cmd, server=self.servers[0], check_res=False)
                 if check_results["code"] == 0:
                     log.warning("{} helm部署记录中已经存在，不做更新，如需要更新，可以先行删除".format(process))
@@ -60,28 +62,29 @@ class CommanderController(ServiceInterface):
                     self._create_logs_dir(service)
                     file_path = os.path.join(self.service_charts_remote, process)
                     # print(file_path)
-                    config_server = "\,".join(
-                        [
-                            "{}:{}".format(
-                                server, self.middleware_cfg["redis"]["port_sentinel"]
-                            ) for server in self.middleware_servers.get_role_ip("master")
-                        ]
-                    )
-                    cmd = """helm --host=localhost:44134 install --name={process} --set replicaCount={replicas} \
-                    --set image.hub={registry_hub} --set image.name={image_name} --set image.tag={image_tag} \
-                    --set pvtWorkDir={pvt_work_dir} \
-                    --set config.server="{config_server}" --set config.passwd={config_server_passwd} \
-                    --set mysql.host={mysql_host} --set mysql.port={mysql_port} --set mysql.user={mysql_user} \
-                    --set mysql.password={mysql_password} --set mysql.database={mysql_database} --set mysql.charset={mysql_charset} \
-                    --set oidc.authority={oidc_authority} --set oidc.secret={oidc_secret} \
-                    {file_path}""".format(
+                    if self.middleware_cfg["redis"]["is_deploy"]:
+                        config_server = "\,".join(
+                            [
+                                "{}:{}\,serviceName={}\,allowAdmin=true".format(
+                                    server,
+                                    self.middleware_cfg["redis"]["port_sentinel"],
+                                    self.middleware_cfg["redis"]["master_name"]
+                                ) for server in self.middleware_servers.get_role_ip("master")
+                            ]
+                        )
+                    else:
+                        config_server = "{}:{}".format(self.middleware_cfg["redis"]["ipaddress"][0],
+                                                       self.middleware_cfg["redis"]["port"])
+
+                    cmd = HELM_INSTALL_COMMANDER.format(
                         process=process, replicas=self.replicas,
                         registry_hub=path_join(self.registry_hub, project),
                         image_name=process, image_tag=version,
                         pvt_work_dir=self.deploy_dir,
                         config_server=config_server,
                         config_server_passwd=self.middleware_cfg["redis"]["password"],
-                        mysql_host="mysql.default.svc", mysql_port=6033, mysql_user=self.middleware_cfg["mysql"]["username"],
+                        mysql_host=self.mysql_host, mysql_port=self.mysql_port,
+                        mysql_user=self.middleware_cfg["mysql"]["username"],
                         mysql_password=self.middleware_cfg["mysql"]["password"],
                         etcd_endpoint=self.etcd_endpoint, mysql_database="uibot_global",
                         mysql_charset="utf8mb4",
@@ -91,6 +94,45 @@ class CommanderController(ServiceInterface):
 
                     self._exec_command_to_host(cmd=cmd, server=self.servers[0])
 
+    def upgrade_service(self, project):
+        for service, processes in self.service_path.config.services.items():
+            for process in processes:
+                log.info("{}开始更新".format(process))
+                self._create_logs_dir(service)
+                file_path = os.path.join(self.service_path, "charts", process)
+
+                if self.middleware_cfg["redis"]["is_deploy"]:
+                    config_server = "\,".join(
+                        [
+                            "{}:{}\,serviceName={}\,allowAdmin=true".format(
+                                server,
+                                self.middleware_cfg["redis"]["port_sentinel"],
+                                self.middleware_cfg["redis"]["master_name"]
+                            ) for server in self.middleware_servers.get_role_ip("master")
+                        ]
+                    )
+                else:
+                    config_server = "{}:{}".format(self.middleware_cfg["redis"]["ipaddress"][0],
+                                                   self.middleware_cfg["redis"]["port"])
+
+                cmd = COMMANDER_UPGRADE_INSTALL.format(
+                    process=process, replicas=self.replicas,
+                    registry_hub=path_join(self.registry_hub, project),
+                    image_name=process, image_tag=self.private_deploy_version,
+                    pvt_work_dir=self.deploy_dir,
+                    config_server=config_server,
+                    config_server_passwd=self.middleware_cfg["redis"]["password"],
+                    mysql_host=self.mysql_host, mysql_port=self.mysql_port,
+                    mysql_user=self.middleware_cfg["mysql"]["username"],
+                    mysql_password=self.middleware_cfg["mysql"]["password"],
+                    etcd_endpoint=self.etcd_endpoint, mysql_database="uibot_global",
+                    mysql_charset="utf8mb4",
+                    oidc_authority="http://{}:{}".format(self.middleware_cfg["identity"]["lb"], self.middleware_cfg["identity"]["nginx_proxy_port"]),
+                    oidc_secret="laiye",
+                    file_path=file_path)
+
+                self._exec_command_to_host(cmd=cmd, server=self.servers[0])
+
     @status_me("commander")
     def start_commander_service(self):
         self.start_service(project=self.project, version=self.private_deploy_version)
@@ -122,23 +164,23 @@ class CommanderController(ServiceInterface):
                 )
                 if not cli.bucket_exists(bucket):
                     cli.make_bucket(bucket)
-                    policy_read_only = {
-                        "Version": "2012-10-17",
-                        "Statement": [
-                            {
-                                "Action": [
-                                    "s3:GetObject"
-                                ],
-                                "Effect": "Allow",
-                                "Principal": "*",
-                                "Resource": [
-                                    "arn:aws:s3:::{}/*".format(bucket)
-                                ],
-                                "Sid": ""
-                            }
-                        ]
-                    }
-                    cli.set_bucket_policy(bucket, json.dumps(policy_read_only))
+                    # policy_read_only = {
+                    #     "Version": "2012-10-17",
+                    #     "Statement": [
+                    #         {
+                    #             "Action": [
+                    #                 "s3:GetObject"
+                    #             ],
+                    #             "Effect": "Allow",
+                    #             "Principal": "*",
+                    #             "Resource": [
+                    #                 "arn:aws:s3:::{}/*".format(bucket)
+                    #             ],
+                    #             "Sid": ""
+                    #         }
+                    #     ]
+                    # }
+                    # cli.set_bucket_policy(bucket, json.dumps(policy_read_only))
 
             except Exception as e:
                 log.error("Minio初始化数据失败:{}".format(e))
@@ -169,8 +211,8 @@ class CommanderController(ServiceInterface):
         log.info("租户平台配置MySql数据库")
         db_mysql = {
             "name": "mysql-1",
-            "host": "mysql.default.svc",
-            "port": 6033,
+            "host": self.mysql_host,
+            "port": self.mysql_port,
             "dbName": "uibot_rpa",
             "userName": self.middleware_cfg.mysql.username,
             "password": self.middleware_cfg.mysql.password,
@@ -187,28 +229,6 @@ class CommanderController(ServiceInterface):
             log.error("配置MySQL数据库失败")
             exit(2)
 
-    def tenant_init_es(self, auth_cookie):
-        log.info("租户平台配置ES数据库")
-        db_es = {
-            "name": "elastic-1",
-            "host": ",".join(self.middleware_cfg["k8s_masters"]),
-            "port": self.middleware_cfg.elasticsearch.http_port,
-            "dbName": "uibot",
-            "userName": self.middleware_cfg.elasticsearch.username,
-            "password": self.middleware_cfg.elasticsearch.password,
-            "type": "110"
-        }
-        rabbitmq_url = "http://{host}:{port}/api/global/database/create".format(
-            host=self.middleware_cfg.nginx.lb, port=self.middleware_cfg.nginx.commander_tenant_port
-        )
-        resp2 = requests.post(rabbitmq_url, json=db_es, cookies=auth_cookie)
-        json_resp2 = resp2.json()
-        if json_resp2['code'] == 0:
-            log.info("配置ES数据库完成")
-        else:
-            log.error("配置ES数据库失败")
-            exit(2)
-
     @status_me("commander")
     def init_tenant(self):
         counter = 0
@@ -219,7 +239,6 @@ class CommanderController(ServiceInterface):
             try:
                 auth_cookie = self.login_tenant()
                 self.tenant_init_mysql(auth_cookie=auth_cookie)
-                self.tenant_init_es(auth_cookie=auth_cookie)
                 succeed = True
 
             except Exception as e:
