@@ -14,10 +14,17 @@ class OcrStandardController(ServiceInterface):
         self.ocr_ctpn_model_data_remote = path_join(self.deploy_dir, "ocr-ctpn-tf-server")
         self.ocr_text_recognition_data_src = path_join(self.data_dir, "ocr-text-recognition-tf-server")
         self.ocr_text_recognition_data_remote = path_join(self.deploy_dir, "ocr-text-recognition-tf-server")
+        self.semantic_correct_src = path_join(self.data_dir, "semantic_correct")
+        self.semantic_correct_remote = path_join(self.deploy_dir, "semantic_correct")
+        self.unet_table_src = path_join(self.data_dir, "unit-table")
+        self.unet_table_remote = path_join(self.deploy_dir, "unit-table")
+
 
     def prepare_ocr(self):
         self._send_file(src=self.ocr_ctpn_model_data_src, dest=self.ocr_ctpn_model_data_remote)
         self._send_file(src=self.ocr_text_recognition_data_src, dest=self.ocr_text_recognition_data_remote)
+        self._send_file(src=self.semantic_correct_src, dest=self.semantic_correct_remote)
+        self._send_file(src=self.unet_table_src, dest=self.unet_table_remote)
 
     def run(self):
         self.prepare_ocr()
