@@ -10,6 +10,10 @@ from laipvt.sysutil.util import path_join, ssh_obj, log, status_me
 
 from laipvt.sysutil.template import FileTemplate
 from laipvt.model.cmd import KubeModel
+from laipvt.sysutil.command import BASH_RUN, CP_KUBEADM, KUBE_INIT, CREATE_KUBE_DIR, CP_KUBE_CONFIG, \
+    KUBECTL_COMPLETION, KUBECTL_APPLY, KUBEADM_TOKEN_CREATE, TAR_KUBE_CRETS, UNTAR_KUBE_CRETS, ADD_MASTER_SUFFIX, \
+    TAINT_MASTER, HELM_PATH, TILLER_PATH, TILLER_SERVICE_PATH, CHMOD_EXECUTE, SYSTEMCTL_DAEMON_RELOAD, SYSTEMCTL_START, \
+    SYSTEMCTL_ENABLE, ISTIOCTL_PATH, ISTIOCTL_INSTALL, CHECK_ISTIO
 
 
 class KubeInterface:
@@ -125,7 +129,7 @@ class KubeInterface:
         self._send_file(self.info["k8s-rpms"], path_join(self.base_dir, "k8s-rpms"))
         cmd_list = [
             # "rpm -ivUh {}/*.rpm --force --nodeps".format(path_join(self.base_dir, "k8s-rpms")),
-            "unalias -a; cp -f {}/kubeadm /usr/bin/kubeadm".format(path_join(self.base_dir, "k8s-rpms"))
+            CP_KUBEADM.format(path_join(self.base_dir, "k8s-rpms"))
         ]
         for server in self.servers:
             log.info("{} 替换kubeadm执行文件".format(server.ipaddress))
@@ -135,7 +139,7 @@ class KubeInterface:
     def system_prepare(self):
         self._generate_file(template_file=self.system_init_template, dest_file=self.system_init_file)
         self._send_file(self.system_init_file, path_join(self.base_dir, "init_env.sh"))
-        cmd = "bash {}".format(path_join(self.base_dir, "init_env.sh"))
+        cmd = BASH_RUN.format(path_join(self.base_dir, "init_env.sh"))
         for server in self.servers:
             log.info("{}执行初始化脚本{}".format(server.ipaddress, path_join(self.base_dir, "init_env.sh")))
             self._exec_command_to_host(cmd=cmd, server=server)
@@ -145,19 +149,19 @@ class KubeInterface:
         log.info("初始化master主节点")
         self._generate_file(template_file=self.kube_admin_file_template, dest_file=self.kube_admin_file)
         self._send_file(self.kube_admin_file, path_join(self.base_dir, "admin.conf"))
-        cmd = "kubeadm init --config {}".format(path_join(self.base_dir, "admin.conf"))
+        cmd = KUBE_INIT.format(path_join(self.base_dir, "admin.conf"))
         self._exec_command_to_host(cmd=cmd, server=self.master)
         cmd = [
-            "mkdir ~/.kube",
-            "cp /etc/kubernetes/admin.conf ~/.kube/config"
+            CREATE_KUBE_DIR,
+            CP_KUBE_CONFIG
         ]
         self._exec_command_to_host(cmd=cmd, server=self.master)
 
     def cp_kube_config(self):
         log.info("拷贝kubectl config文件")
         cmd = [
-            "mkdir ~/.kube",
-            "cp /etc/kubernetes/admin.conf ~/.kube/config"
+            CREATE_KUBE_DIR,
+            CP_KUBE_CONFIG
         ]
         for server in self.all_servers:
             self._exec_command_to_host(cmd=cmd, server=server, check_res=False)
@@ -165,7 +169,7 @@ class KubeInterface:
     @status_me("basesystem")
     def kube_completion(self):
         log.info("k8s命令自动补全")
-        cmd = "echo 'source <(kubectl completion bash)' >> ~/.bashrc"
+        cmd = KUBECTL_COMPLETION
         self._exec_command_to_host(cmd=cmd, server=self.master)
 
     @status_me("basesystem")
@@ -173,11 +177,11 @@ class KubeInterface:
         log.info("部署flannel网络插件")
         self._generate_file(template_file=self.flannel_template, dest_file=self.flannel_file)
         self._send_file(self.flannel_file, path_join(self.base_dir, "kube-flannel.yaml"))
-        cmd = "kubectl apply -f {}".format(path_join(self.base_dir, "kube-flannel.yaml"))
+        cmd = KUBECTL_APPLY.format(path_join(self.base_dir, "kube-flannel.yaml"))
         self._exec_command_to_host(cmd=cmd, server=self.master)
 
     def get_kube_admin_join_command(self) -> str:
-        cmd = "kubeadm token create --print-join-command --config {}".format(path_join(self.base_dir, "admin.conf"))
+        cmd = KUBEADM_TOKEN_CREATE.format(path_join(self.base_dir, "admin.conf"))
         res = self._exec_command_to_host(cmd=cmd, server=self.master)
 
         if res["code"] == 0 and "kubeadm join" in res["stdout"]:
@@ -189,9 +193,7 @@ class KubeInterface:
     def join_master(self):
         # 1、连接master-01，打包需要拷贝的证书配置，拉到本地
         log.info("将master-01 kubernetes证书拉回本地，发送至其余master节点")
-        cmd = """tar -C /etc/kubernetes -zcvf {} \
-        admin.conf pki/ca.crt pki/ca.key pki/sa.key pki/sa.pub pki/front-proxy-ca.crt \
-        pki/front-proxy-ca.key pki/etcd/ca.crt pki/etcd/ca.key""".format(self.remote_pki_path)
+        cmd = TAR_KUBE_CRETS.format(self.remote_pki_path)
         self._exec_command_to_host(cmd=cmd, server=self.master)
         self._get_file(src=self.remote_pki_path, dest=path_join(self.local_tmp, self.pki_tar_name), server=self.master)
 
@@ -204,12 +206,12 @@ class KubeInterface:
         for i, server in enumerate(other_masters):
             log.info("将kubernetes证书，发送至master节点{},并解压".format(server.ipaddress))
             self._send_file(src=path_join(self.local_tmp, self.pki_tar_name), dest=self.remote_pki_path)
-            cmd = "tar -zxvf {} -C /etc/kubernetes/".format(self.remote_pki_path)
+            cmd = UNTAR_KUBE_CRETS.format(self.remote_pki_path)
             self._exec_command_to_host(cmd=cmd, server=server)
 
             log.info("加入{}master节点".format(server.ipaddress))
             node_name = "master-0{}".format(i + 2)
-            cmd = "{} --control-plane --node-name {}".format(join_cmd, node_name)
+            cmd = ADD_MASTER_SUFFIX.format(join_cmd, node_name)
             self._exec_command_to_host(cmd=cmd, server=server)
 
     @status_me("basesystem")
@@ -218,7 +220,7 @@ class KubeInterface:
             if server.ipaddress in self.result.servers.get_role_ip("master"):
                 log.info("master")
                 node_name = "master-0{}".format(i + 1)
-                cmd = "kubectl taint nodes {} node-role.kubernetes.io/master-".format(node_name)
+                cmd = TAINT_MASTER.format(node_name)
             else:
                 cmd = self.get_kube_admin_join_command()
             self._exec_command_to_host(cmd=cmd, server=self.master)
@@ -234,38 +236,36 @@ class KubeInterface:
 
     @status_me("basesystem")
     def install_helm(self):
-        self._send_file(src=path_join(self.info.plugin.helm, "bin/helm"), dest="/usr/bin/helm")
-        self._send_file(src=path_join(self.info.plugin.helm, "bin/tiller"), dest="/usr/bin/tiller")
+        self._send_file(src=path_join(self.info.plugin.helm, "bin/helm"), dest=HELM_PATH)
+        self._send_file(src=path_join(self.info.plugin.helm, "bin/tiller"), dest=TILLER_PATH)
         self._send_file(
             src=path_join(self.info.plugin.helm, "service/tiller.service"),
-            dest="/usr/lib/systemd/system/tiller.service"
+            dest=TILLER_SERVICE_PATH
         )
         cmd_list = [
-            "chmod +x /usr/bin/helm", "chmod +x /usr/bin/tiller",
-            "systemctl daemon-reload", "systemctl start tiller.service", "systemctl enable tiller.service"
+            CHMOD_EXECUTE.format(HELM_PATH), CHMOD_EXECUTE.format(TILLER_PATH),
+            SYSTEMCTL_DAEMON_RELOAD, SYSTEMCTL_START.format("tiller.service"), SYSTEMCTL_ENABLE.format("tiller.service")
         ]
         self._exec_command_to_host(cmd=cmd_list, server=self.master, check_res=True)
 
     @status_me("basesystem")
     def install_istio(self):
-        self._send_file(src=path_join(self.info.plugin.istio, "bin/istioctl"), dest="/usr/bin/istioctl")
+        self._send_file(src=path_join(self.info.plugin.istio, "bin/istioctl"), dest=ISTIOCTL_PATH)
 
         self._generate_file(template_file=self.istio_template, dest_file=self.istio_file)
         istio_remote_file = path_join(self.base_dir, "istio-private-deploy.yaml")
         self._send_file(src=self.istio_file, dest=istio_remote_file)
 
-        cmd = "chmod +x /usr/bin/istioctl && istioctl version || exit 2"
+        cmd = CHMOD_EXECUTE.format(ISTIOCTL_PATH)
         self._exec_command_to_host(cmd=cmd, server=self.master, check_res=True)
 
         log.info("安装Istio")
-        install_cmd = "istioctl install -f {}".format(
-            path_join(self.base_dir, "istio-private-deploy.yaml")
-        )
+        install_cmd = ISTIOCTL_INSTALL.format(path_join(self.base_dir, "istio-private-deploy.yaml"))
         self._exec_command_to_host(cmd=install_cmd, server=self.master, check_res=True)
 
         log.info("检查Istio")
         time.sleep(30)
-        check_cmd = "kubectl get crds | grep 'istio.io' | wc -l"
+        check_cmd = CHECK_ISTIO
         res = self._exec_command_to_host(cmd=check_cmd, server=self.master, check_res=True)
         try:
             if int(res["stdout"]) != 21:
