@@ -1,9 +1,10 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 import re
+import os
 import pymysql
 from laipvt.helper.exception import ModelError
-from laipvt.sysutil.util import run_local_cmd
+from laipvt.sysutil.util import path_join, run_local_cmd, backup_file
 
 
 class SqlModule(object):
@@ -15,6 +16,12 @@ class SqlModule(object):
             kwargs.get("passwd"),
             kwargs.get("port")
         )
+        self.mysqldump_cmd = "mysqldump -h {} -u{} -p{} -P{}".format(
+            kwargs.get("host"),
+            kwargs.get("user"),
+            kwargs.get("passwd"),
+            kwargs.get("port")
+        )
 
     def use_db(self, db_name):
         self.conn.select_db(db_name)
@@ -101,6 +108,7 @@ class SqlModule(object):
 
     def select(self, sql_statements):
         cursor = self.conn.cursor(cursor=pymysql.cursors.DictCursor)
+        info = None
         try:
             cursor.execute(sql_statements)
             info = cursor.fetchall()
@@ -120,8 +128,18 @@ class SqlModule(object):
             cursor.close()
 
     def import_from_dir(self, db, path):
-        cmd = "for i in $(ls {}), do {} {} < $i; done".format(path, self.mysql_cmd, db)
+        cmd = "for i in $(ls {}); do {} {} < {}/$i; done".format(path, self.mysql_cmd, db, path)
         run_local_cmd(cmd)
 
+    def backup_db(self, db, target):
+        target_file_path = path_join(target, db + ".sql")
+        if os.path.isfile(target_file_path):
+            backup_file(target_file_path)
+        cmd = "{} {}".format(self.mysqldump_cmd, "{} > {}".format(
+            db, target_file_path
+        ))
+        res = run_local_cmd(cmd)
+        return True if res["code"] == 0 else False
+
     def close(self):
         self.conn.close()
\ No newline at end of file
