@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import os
 import json
 import re
+import time
 import string
 import shutil
 import array
@@ -271,3 +272,11 @@ def read_form_json_file(file_name):
 def get_value_form_file(file_path, key):
     c = get_yaml_config(file_path)
     return c.get(key, False)
+
+def backup_file(path):
+    dir = os.path.dirname(path)
+    if os.path.isdir(dir):
+        backup_file_suffix = ".bak-%d" % int(time.time() * 1000)
+        file_name = os.path.split(path)[1]
+        backup_file = os.path.join(dir, file_name + backup_file_suffix)
+        shutil.copyfile(path, backup_file)
\ No newline at end of file
